flutter_zxing library
Classes
- CameraController
- Controls a device camera.
- Code
- Codes
- DecodeParams
- Encode
- EncodeParams
- Format
- ImageFormat
- Messages
- MultiResultOverlay
- MultiScanPainter
- Position
- Represents the position of a barcode in an image.
- ReaderWidget
- Widget to scan a code from the camera stream
- ScannerOverlayBorder
- Universal border for a scanner overlay with a transparent cut-out. cutOutSize > 1 — size in pixels, <= 1 — percentage of the smaller side. Offsets: -1.0..1.0 (left/right, up/down).
- WriterWidget
- Widget to create a code from a text and barcode format
- Zxing
Enums
- CameraLensDirection
- The direction the camera is facing.
- EccLevel
- ResolutionPreset
- Affect the quality of video recording and image capture:
Extensions
Properties
-
barcodeDemoText
→ Map<
int, String> -
final
-
barcodeMaxTextLengths
→ Map<
int, int> -
final
-
barcodeNames
→ Map<
int, String> -
final
-
barcodeRatios
→ Map<
int, double> -
final
- zx → Zxing
-
final
Functions
-
convertImage(
CameraImage image) → Future< Uint8List> -
pngFromBytes(
Uint8List bytes, int width, int height) → Uint8List -
resizeToMaxSize(
Image image, int? maxSize) → Image -
rgbBytes(
Image image) → Uint8List -
tightlyPackedYPlaneFromCameraImage(
CameraImage image) → Uint8List