format property
ImageFormat
format
final
Format of the image provided.
Determines the number of planes needed to represent the image, and the general layout of the pixel data in each Uint8List.
Implementation
final ImageFormat format;