Position class

Represents the position of a barcode in an image.

Constructors

Position(int imageWidth, int imageHeight, int topLeftX, int topLeftY, int topRightX, int topRightY, int bottomLeftX, int bottomLeftY, int bottomRightX, int bottomRightY)

Properties

bottomLeftX ↔ int
getter/setter pair
bottomLeftY ↔ int
getter/setter pair
bottomRightX ↔ int
getter/setter pair
bottomRightY ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
imageHeight ↔ int
getter/setter pair
imageWidth ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
topLeftX ↔ int
getter/setter pair
topLeftY ↔ int
getter/setter pair
topRightX ↔ int
getter/setter pair
topRightY ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited