CodeResults class final

@brief The CodeResults class encapsulates the result of decoding multiple barcodes within an image.

Inheritance
Implemented types
Available extensions

Constructors

CodeResults()

Properties

address → Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
count ↔ int
< The number of barcodes detected
getter/setter pair
duration ↔ int
< The duration of the decoding in milliseconds
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
results ↔ Pointer<CodeResult>
< The results of the barcode decoding. Owned pointer. Must be freed by Dart code.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

$allocate(Allocator $allocator, {required int count, required Pointer<CodeResult> results, required int duration}) → Pointer<CodeResults>