DecodeBarcodeParams class final

@brief The BarcodeParams class encapsulates parameters for reading barcodes.

Inheritance
Implemented types
Available extensions

Constructors

DecodeBarcodeParams()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
bytes Pointer<Uint8>
< Image bytes. Owned pointer, freed in destructor.
getter/setter pair
cropHeight int
< Crop height
getter/setter pair
cropLeft int
< Crop left
getter/setter pair
cropTop int
< Crop top
getter/setter pair
cropWidth int
< Crop width
getter/setter pair
format int
< Specify a set of BarcodeFormats that should be searched for
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
height int
< Image height in pixels
getter/setter pair
imageFormat int
< Image format
getter/setter pair
length int
< Size of the bytes buffer, in bytes. Used to reject out-of-bounds reads.
getter/setter pair
maxNumberOfSymbols int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tryDownscale bool
< try detecting code in downscaled images (depending on image size).
getter/setter pair
tryHarder bool
< Spend more time to try to find a barcode, optimize for accuracy, not speed
getter/setter pair
tryInvert bool
< Try inverting the image
getter/setter pair
tryRotate bool
< Also try detecting code in 90, 180 and 270 degree rotated images
getter/setter pair
width int
< Image width in pixels
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

$allocate(Allocator $allocator, {required Pointer<Uint8> bytes, required int length, required int imageFormat, required int format, required int width, required int height, required int cropLeft, required int cropTop, required int cropWidth, required int cropHeight, required bool tryHarder, required bool tryRotate, required bool tryInvert, required bool tryDownscale, required int maxNumberOfSymbols}) Pointer<DecodeBarcodeParams>