EncodeResult class final

@brief EncodeResult encapsulates the result of encoding a barcode.

Inheritance
Implemented types
Available extensions

Constructors

EncodeResult()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
data Pointer<Uint8>
< The encoded data, one byte per pixel. Owned pointer. Must be freed by Dart code if not null.
getter/setter pair
error Pointer<Char>
< The error message. Owned pointer. Must be freed by Dart code if not null.
getter/setter pair
format int
< The format of the barcode
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
height int
< The height of the encoded bitmap in pixels. May differ from the requested height if the symbol does not fit.
getter/setter pair
isValid bool
< Whether the barcode was successfully encoded
getter/setter pair
length int
< The length of the encoded data, equal to width * height
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width int
< The width of the encoded bitmap in pixels. May be larger than the requested width if the symbol does not fit.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toEncode(String text) Encode

Available on EncodeResult, provided by the EncodeExt extension

toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

$allocate(Allocator $allocator, {required bool isValid, required int format, required Pointer<Uint8> data, required int length, required Pointer<Char> error, required int width, required int height}) Pointer<EncodeResult>