Code class
Constructors
Properties
- duration ↔ int
-
getter/setter pair
- error ↔ String?
-
getter/setter pair
- format ↔ int?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- imageBytes ↔ Uint8List?
-
The image the decoder actually scanned, as one byte per pixel.
getter/setter pair
- imageHeight ↔ int?
-
Height of imageBytes. See imageWidth.
getter/setter pair
- imageWidth ↔ int?
-
Width of imageBytes, which is the scanned (cropped) region, not
necessarily the width of the image that was passed in.
getter/setter pair
- isInverted ↔ bool
-
getter/setter pair
- isMirrored ↔ bool
-
getter/setter pair
- isValid ↔ bool
-
getter/setter pair
- position ↔ Position?
-
getter/setter pair
- rawBytes ↔ Uint8List?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source ↔ CodeSource?
-
getter/setter pair
- text ↔ String?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited